# A test file for test_pytest_cov.py:test_contexts

import unittest

import pytest


def test_01():
    assert 1 == 1                                   # r1


def test_02():
    assert 2 == 2                                   # r2


class OldStyleTests(unittest.TestCase):
    items = []

    @classmethod
    def setUpClass(cls):
        cls.items.append("hello")                   # s3

    @classmethod
    def tearDownClass(cls):
        cls.items.pop()                             # t4

    def setUp(self):
        self.number = 1                             # r3 r4

    def tearDown(self):
        self.number = None                          # r3 r4

    def test_03(self):
        assert self.number == 1                     # r3
        assert self.items[0] == "hello"             # r3

    def test_04(self):
        assert self.number == 1                     # r4
        assert self.items[0] == "hello"             # r4


@pytest.fixture
def some_data():
    return [1, 2, 3]                                # s5 s6


def test_05(some_data):
    assert len(some_data) == 3                      # r5


@pytest.fixture
def more_data(some_data):
    return [2*x for x in some_data]                 # s6


def test_06(some_data, more_data):
    assert len(some_data) == len(more_data)         # r6


@pytest.fixture(scope='session')
def expensive_data():
    return list(range(10))                          # s7


def test_07(expensive_data):
    assert len(expensive_data) == 10                # r7


def test_08(expensive_data):
    assert len(expensive_data) == 10                # r8


@pytest.fixture(params=[1, 2, 3])
def parametrized_number(request):
    return request.param                            # s9-1 s9-2 s9-3


def test_09(parametrized_number):
    assert parametrized_number > 0                  # r9-1 r9-2 r9-3


def test_10():
    assert 1 == 1                                   # r10


@pytest.mark.parametrize("x, ans", [
    (1, 101),
    (2, 202),
])
def test_11(x, ans):
    assert 100 * x + x == ans                       # r11-1 r11-2


@pytest.mark.parametrize("x, ans", [
    (1, 101),
    (2, 202),
], ids=['one', 'two'])
def test_12(x, ans):
    assert 100 * x + x == ans                       # r12-1 r12-2


@pytest.mark.parametrize("x", [1, 2])
@pytest.mark.parametrize("y", [3, 4])
def test_13(x, y):
    assert x + y > 0                                # r13-1 r13-2 r13-3 r13-4



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function

import io
import re
from distutils.command.build import build
from glob import glob
from itertools import chain
from os.path import basename
from os.path import dirname
from os.path import join
from os.path import splitext

from setuptools import Command
from setuptools import find_packages
from setuptools import setup
from setuptools.command.develop import develop
from setuptools.command.easy_install import easy_install
from setuptools.command.install_lib import install_lib


def read(*names, **kwargs):
    with io.open(
        join(dirname(__file__), *names),
        encoding=kwargs.get('encoding', 'utf8')
    ) as fh:
        return fh.read()


class BuildWithPTH(build):
    def run(self):
        build.run(self)
        path = join(dirname(__file__), 'src', 'pytest-cov.pth')
        dest = join(self.build_lib, basename(path))
        self.copy_file(path, dest)


class EasyInstallWithPTH(easy_install):
    def run(self):
        easy_install.run(self)
        path = join(dirname(__file__), 'src', 'pytest-cov.pth')
        dest = join(self.install_dir, basename(path))
        self.copy_file(path, dest)


class InstallLibWithPTH(install_lib):
    def run(self):
        install_lib.run(self)
        path = join(dirname(__file__), 'src', 'pytest-cov.pth')
        dest = join(self.install_dir, basename(path))
        self.copy_file(path, dest)
        self.outputs = [dest]

    def get_outputs(self):
        return chain(install_lib.get_outputs(self), self.outputs)


class DevelopWithPTH(develop):
    def run(self):
        develop.run(self)
        path = join(dirname(__file__), 'src', 'pytest-cov.pth')
        dest = join(self.install_dir, basename(path))
        self.copy_file(path, dest)


class GeneratePTH(Command):
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        with open(join(dirname(__file__), 'src', 'pytest-cov.pth'), 'w') as fh:
            with open(join(dirname(__file__), 'src', 'pytest-cov.embed')) as sh:
                fh.write(
                    'import os, sys;'
                    'exec(%r)' % sh.read().replace('    ', ' ')
                )


setup(
    name='pytest-cov',
    version='2.10.1',
    license='MIT',
    description='Pytest plugin for measuring coverage.',
    long_description='%s\n%s' % (read('README.rst'), re.sub(':[a-z]+:`~?(.*?)`', r'``\1``', read('CHANGELOG.rst'))),
    author='Marc Schlaich',
    author_email='marc.schlaich@gmail.com',
    url='https://github.com/pytest-dev/pytest-cov',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    py_modules=[splitext(basename(path))[0] for path in glob('src/*.py')],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        # complete classifier list: http://pypi.python.org/pypi?%3Aaction=list_classifiers
        'Development Status :: 5 - Production/Stable',
        'Framework :: Pytest',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Software Development :: Testing',
        'Topic :: Utilities',
    ],
    keywords=[
        'cover', 'coverage', 'pytest', 'py.test', 'distributed', 'parallel',
    ],
    install_requires=[
        'pytest>=4.6',
        'coverage>=4.4'
    ],
    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*',
    extras_require={
        'testing': [
            'fields',
            'hunter',
            'process-tests==2.0.2',
            'six',
            'pytest-xdist',
            'virtualenv',
        ]
    },
    entry_points={
        'pytest11': [
            'pytest_cov = pytest_cov.plugin',
        ],
        'console_scripts': [
        ]
    },
    cmdclass={
        'build': BuildWithPTH,
        'easy_install': EasyInstallWithPTH,
        'install_lib': InstallLibWithPTH,
        'develop': DevelopWithPTH,
        'genpth': GeneratePTH,
    },
)
